<?php
/**
 * Elementor Blog area one
 * @since 1.0.0
 */
use Elementor\Utils;

class Blog_area__o extends \Elementor\Widget_Base {

    public function get_name() {
        return 'blog_area__o';
    }

    public function get_title() {
        return __('Blog area one', 'plugin-name');
    }

    public function get_icon() {
        return 'fa fa-object-ungroup';
    }

    public function get_categories() {
        return ['plugin-domain'];
    }

    private function get_blog_categories() {
        $options = array();
        $taxonomy = 'category';
        if (!empty($taxonomy)) {
            $terms = get_terms(
                    array(
                        'parent' => 0,
                        'taxonomy' => $taxonomy,
                        'hide_empty' => true,
                    )
            );
            if (!empty($terms)) {
                foreach ($terms as $term) {
                    if (isset($term)) {
                        if (isset($term->slug) && isset($term->name)) {
                            $options[$term->slug] = $term->name;
                        }
                    }
                }
            }
        }
        return $options;
    }

    protected function _register_controls() {
        $this->start_controls_section(
            'section_blogs', [
            'label' => __('Blog post list', 'plugin-name'),
            'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
                ]
        );
        $this->add_control(
			'icon_style',
			[
				'label' => esc_html__( 'Icon Position', 'plugin-domain' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => '1',
				'options' => [
					'1'  => esc_html__( 'One', 'plugin-domain' ),
					'2' => esc_html__( 'Two', 'plugin-domain' ),
				],
			]
		);
        $this->add_control(
            'titles',
            [
                'label' => esc_html__( 'title content', 'kahaf' ),
                'type' => \Elementor\Controls_Manager::TEXTAREA,
            ]
        );
        $this->add_control(
            'sub_titles',
            [
                'label' => esc_html__( 'sub title content', 'kahaf' ),
                'type' => \Elementor\Controls_Manager::TEXTAREA,
            ]
        );
        $this->add_control(
                'catagory_name', [
            'type' => \Elementor\Controls_Manager::SELECT,
            'label' => esc_html__('Category', 'plugin-name'),
            'options' => $this->get_blog_categories()
                ]
        );
        $this->add_control(
                'posts_per_page', [
            'label' => esc_html__('Posts per Page', 'plugin-name'),
            'type' => \Elementor\Controls_Manager::NUMBER,
            'min' => 0,
            'max' => 20,
            'step' => 1,
            'default' => 10,
                ]
        );
        $this->add_control(
                'order_by', [
            'label' => esc_html__('Order by', 'plugin-name'),
            'type' => \Elementor\Controls_Manager::SELECT,
            'options' => [
                'date' => esc_html__('Date', 'plugin-name'),
                'ID' => esc_html__('ID', 'plugin-name'),
                'author' => esc_html__('Author', 'plugin-name'),
                'title' => esc_html__('Title', 'plugin-name'),
                'modified' => esc_html__('Modified', 'plugin-name'),
                'rand' => esc_html__('Random', 'plugin-name'),
                'menu_order' => esc_html__('Menu order', 'plugin-name'),
            ],
            'default' => esc_html__('ID', 'plugin-name'),
                ]
        );
        $this->add_control(
                'sort_by', [
            'label' => esc_html__('Sort By', 'plugin-name'),
            'type' => \Elementor\Controls_Manager::SELECT,
            'options' => [
                'desc' => esc_html__('desc', 'plugin-name'),
                'asc' => esc_html__('asc', 'plugin-name'),
            ],
            'default' => esc_html__('desc', 'plugin-name'),
                ]
        );
        $this->add_control(
                'extra_class', [
            'label' => esc_html__('Add Extra Class', 'plugin-name'),
            'type' => \Elementor\Controls_Manager::TEXT
                ]
        );
        $this->end_controls_section();
    }

    protected function render() {
        $settings = $this->get_settings_for_display();

        $posts_per_page = $settings['posts_per_page'];
        $catagory_name = ucwords($settings['catagory_name']);
        $order_by = $settings['order_by'];
        $sort_by = $settings['sort_by'];

        $title = $settings["titles"];
        $icon_style = $settings["icon_style"];
        $sub_title = $settings["sub_titles"];
        ?>


<section class="news-section grid-addons-news">
        <div class="anim-icon">
            <div class="icon icon-<?php echo esc_attr( $icon_style ); ?> wow zoomIn" data-wow-delay="00ms" data-wow-duration="1500ms"></div>
        </div>
        <div class="container">
            <div class="sec-title centred">
                <h5><?php echo $title; ?></h5>
                <h1><?php echo $sub_title; ?></h1>
            </div>
            <div class="row">

            <?php
                            $args = array(
                                'category_name' => $catagory_name,
                                'orderby' => $order_by,
                                'order' => $sort_by,
                                'posts_per_page' => $posts_per_page,
                            );
                            global $wpdb;
                            $loop = new WP_Query($args);
                            $i = 1;
                            if ($loop->have_posts()) {
                                while ($loop->have_posts()) : $loop->the_post();
                                    if ($i == 1) {
                                        $delay = 0;
                                    } elseif ($i == 2) {
                                        $delay = 300;
                                    } elseif ($i == 3) {
                                        $delay = 600;
                                    } else {
                                        $delay = 0;
                                    }
                                    $is_no_post_thumb = '';
                                    if (!has_post_thumbnail()) :
                                        $is_no_post_thumb = 'no-post-thumb';
                                    endif;
                        ?>
                <div class="col-lg-4 col-md-6 col-sm-12 news-block">
                    <div class="news-block-one wow fadeInUp" data-wow-delay="00ms" data-wow-duration="1500ms">
                        <div class="inner-box">
                            <figure class="image-box"><a href="<?php echo esc_url(get_permalink()); ?>"><?php kidko_post_thumbnail(); ?></a></figure>
                            <div class="lower-content">
                                <h3><a href="<?php echo esc_url(get_permalink()); ?>"><?php the_title(); ?></a></h3>
                                <ul class="info-box">
                                    <li><?php echo get_the_date(); ?></li>
                                    <li><?php kidko_comments_count(); ?></li>
                                </ul>
                                <div class="text"><?php the_excerpt(); ?></div>
                                <div class="link-btn wow zoomIn" data-wow-delay="00ms" data-wow-duration="1500ms"><a href="<?php echo esc_url(get_permalink()); ?>"><i class="flaticon-next"></i></a></div>
                            </div>
                        </div>
                    </div>
                </div>
                <?php
                                $i++;
                                endwhile;
                            } else {
                                echo esc_html__('No products found', 'plugin-name');
                            }
                            wp_reset_postdata();
                        ?>

            </div>
        </div>
    </section>
        <?php
    }
}
\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Blog_area__o() );
