<?php

if (!defined('ABSPATH')) {
    exit;
}



use Elementor\Utils;
use Elementor\Controls_Manager;
use Elementor\Widget_Base;
use Elementor\Plugin;
use \Elementor\Repeater;

class Page_classes_t extends Widget_Base {

    public function get_name() {
        return 'page_classes_t';
    }

    public function get_title() {
        return __('Classes Two', 'plugin-domain');
    }

    public function get_icon() {
        return 'eicon-post';
    }

    public function get_categories() {
        return ['plugin-domain'];
    }

    protected function _register_controls() {

        $this->start_controls_section(
                'section_page_classes_t', [
            'label' => __('Class', 'plugin-domain'),
                ]
        );

        $this->add_control(
                'title_1', [
            'label' => __('Title 1', 'plugin-domain'),
            'label_block' => true,
            'type' => Controls_Manager::TEXT,
            'default' => __('A quick peek at our centre', 'plugin-domain'),
                ]
        );

        $this->add_control(
                'title_2', [
            'label' => __('Title 2', 'plugin-domain'),
            'label_block' => true,
            'type' => Controls_Manager::TEXT,
            'default' => __('ChildiT Centre Photo classes', 'plugin-domain'),
                ]
        );

        $this->add_control(
                'number', [
            'label' => __('Number of classes', 'plugin-domain'),
            'type' => Controls_Manager::TEXT,
            'default' => 16
                ]
        );

        $this->add_control(
                'order_by', [
            'label' => __('Order By', 'plugin-domain'),
            'type' => Controls_Manager::SELECT,
            'default' => 'date',
            'options' => [
                'date' => __('Date', 'plugin-domain'),
                'ID' => __('ID', 'plugin-domain'),
                'author' => __('Author', 'plugin-domain'),
                'title' => __('Title', 'plugin-domain'),
                'modified' => __('Modified', 'plugin-domain'),
                'rand' => __('Random', 'plugin-domain'),
                'comment_count' => __('Comment count', 'plugin-domain'),
                'menu_order' => __('Menu order', 'plugin-domain')
            ]
                ]
        );

        $this->add_control(
                'order', [
            'label' => __('Order', 'plugin-domain'),
            'type' => Controls_Manager::SELECT,
            'default' => 'desc',
            'options' => [
                'desc' => __('DESC', 'plugin-domain'),
                'asc' => __('ASC', 'plugin-domain')
            ]
                ]
        );
        $this->end_controls_section();
    }

    protected function render() {
        $settings = $this->get_settings();
        $title_1 = $settings['title_1'];
        $title_2 = $settings['title_2'];
        $posts_per_page = $settings['number'];
        $order_by = $settings['order_by'];
        $order = $settings['order'];
        $pg_num = max(1, (int) filter_input(INPUT_GET, 'pageid'));
        $args = array(
            'post_type' => 'classess',
            'post_status' => array('publish'),
            'nopaging' => false,
            'paged' => $pg_num,
            'posts_per_page' => $posts_per_page,
            'orderby' => $order_by,
            'order' => $order,
        );
        $query = new \WP_Query($args);
?>

<?php
    if ($query->have_posts()) {
?>



<section class="classes-section style-two sec-pad">
        <div class="parallax-scene parallax-scene-1 parallax-icon">
            <span data-depth="0.40" class="parallax-layer icon icon-1"></span>
            <span data-depth="0.50" class="parallax-layer icon icon-2"></span>
            <span data-depth="0.30" class="parallax-layer icon icon-3"></span>
            <span data-depth="0.40" class="parallax-layer icon icon-4"></span>
            <span data-depth="0.50" class="parallax-layer icon icon-5"></span>
            <span data-depth="0.30" class="parallax-layer icon icon-6"></span>
            <span data-depth="0.40" class="parallax-layer icon icon-7"></span>
        </div>
        <div class="container">
            <div class="sec-title centred">
                <h5><?php echo wp_kses_post( $title_1 ); ?></h5>
                <h1><?php echo wp_kses_post( $title_2 ); ?></h1>
            </div>
            <div class="row">
                <?php
                    while ($query->have_posts()) {
                    $query->the_post();
                    

                        $kidko_theme_metabox_class_cost_name = get_post_meta(get_the_ID(), 'kidko_theme_metabox_class_cost_name', true);
                        $kidko_theme_metabox_class_widget_age = get_post_meta(get_the_ID(), 'kidko_theme_metabox_class_widget_age', true);
                        $kidko_theme_metabox_class_small_image = get_post_meta(get_the_ID(), 'kidko_theme_metabox_class_small_image', array( 'size' => 'full' ));
                ?>
                <div class="col-lg-4 col-md-6 col-sm-12 block-column">
                    <div class="inner-block wow fadeInUp" data-wow-delay="0ms" data-wow-duration="1500ms">
                        <figure class="image-box"><a href="<?php echo esc_url(get_permalink()); ?>"><img src="<?php echo esc_url( wp_get_attachment_url( $kidko_theme_metabox_class_small_image ) );?>" alt=""></a></figure>
                        <div class="lower-content">
                            <div class="link-btn"><a href="<?php echo esc_url(get_permalink()); ?>"><i class="flaticon-next"></i></a></div>
                            <h3><a href="<?php echo esc_url(get_permalink()); ?>"><?php echo get_the_title( ) ?></a></h3>
                            <div class="price"><?php echo wp_kses_post( $kidko_theme_metabox_class_cost_name ); ?></div>
                            <ul class="info-box">
                                <?php echo wp_kses_post( $kidko_theme_metabox_class_widget_age ); ?>
                            </ul>
                        </div>
                    </div>
                </div>
                <?php
                        
                    }
                ?>
            </div>
        </div>
    </section>




<?php
    wp_reset_postdata();
    }
?>

        <?php
    }
}


Plugin::instance()->widgets_manager->register_widget_type( new \Page_classes_t() );