<?php

if (!defined('ABSPATH')) {
    exit;
}



use Elementor\Utils;
use Elementor\Controls_Manager;
use Elementor\Widget_Base;
use Elementor\Plugin;
use \Elementor\Repeater;

class Page_Gallery extends Widget_Base {

    public function get_name() {
        return 'page_gallery';
    }

    public function get_title() {
        return __('Events', 'plugin-domain');
    }

    public function get_icon() {
        return 'eicon-post';
    }

    public function get_categories() {
        return ['plugin-domain'];
    }

    protected function _register_controls() {

        $this->start_controls_section(
                'section_page_gallery', [
            'label' => __('Events', 'plugin-domain'),
                ]
        );

        
        $this->add_control(
                'number', [
            'label' => __('Number of Gallery', 'plugin-domain'),
            'type' => Controls_Manager::TEXT,
            'default' => 16
                ]
        );

        $this->add_control(
                'order_by', [
            'label' => __('Order By', 'plugin-domain'),
            'type' => Controls_Manager::SELECT,
            'default' => 'date',
            'options' => [
                'date' => __('Date', 'plugin-domain'),
                'ID' => __('ID', 'plugin-domain'),
                'author' => __('Author', 'plugin-domain'),
                'title' => __('Title', 'plugin-domain'),
                'modified' => __('Modified', 'plugin-domain'),
                'rand' => __('Random', 'plugin-domain'),
                'comment_count' => __('Comment count', 'plugin-domain'),
                'menu_order' => __('Menu order', 'plugin-domain')
            ]
                ]
        );

        $this->add_control(
                'order', [
            'label' => __('Order', 'plugin-domain'),
            'type' => Controls_Manager::SELECT,
            'default' => 'desc',
            'options' => [
                'desc' => __('DESC', 'plugin-domain'),
                'asc' => __('ASC', 'plugin-domain')
            ]
                ]
        );
        $this->end_controls_section();
    }

    protected function render() {
        $settings = $this->get_settings();
        $posts_per_page = $settings['number'];
        $order_by = $settings['order_by'];
        $order = $settings['order'];
        $pg_num = max(1, (int) filter_input(INPUT_GET, 'pageid'));
        $args = array(
            'post_type' => 'events',
            'post_status' => array('publish'),
            'nopaging' => false,
            'paged' => $pg_num,
            'posts_per_page' => $posts_per_page,
            'orderby' => $order_by,
            'order' => $order,
        );
        $query = new \WP_Query($args);
?>

<?php
    if ($query->have_posts()) {
?>
    <section class="event-page-section">
        <div class="container">
            <div class="row">
                <?php
                    while ($query->have_posts()) {
                    $query->the_post();
                    if (has_post_thumbnail()) {

                        $kidko_theme_metabox_events_widget_location = get_post_meta(get_the_ID(), 'kidko_theme_metabox_events_widget_location', true);
                        $kidko_theme_metabox_events_small_image = get_post_meta(get_the_ID(), 'kidko_theme_metabox_events_small_image', array( 'size' => 'full' ));
                ?>
                    <div class="col-xl-6 col-lg-12 col-md-12 event-block">
                        <div class="event-block-one wow fadeInLeft" data-wow-delay="00ms" data-wow-duration="1500ms">
                            <div class="inner-box">
                                <figure class="image-box"><a href="<?php echo esc_url(get_permalink()); ?>"><img src="<?php echo esc_url( wp_get_attachment_url( $kidko_theme_metabox_events_small_image ) );?>" alt=""></a></figure>
                                <div class="content-box">
                                    <div class="date"><?php echo get_the_date(); ?></div>
                                    <h3><a href="<?php echo esc_url(get_permalink()); ?>"><?php echo get_the_title( ) ?></a></h3>
                                    <div class="text"><?php echo get_the_excerpt(); ?></div>
                                    <div class="location"><i class="flaticon-pin"></i>Location: <span><?php echo wp_kses_post( $kidko_theme_metabox_events_widget_location ); ?></span></div>
                                </div>
                            </div>
                        </div>
                    </div>
                <?php
                        }
                    }
                ?>
                <div class="col-xl-6">
                    <div class="pagination-weapper ri-fat-pagination text-center">
                        <?php
                            $current = max(1, (int) filter_input(INPUT_GET, 'pageid'));
                            echo paginate_links(array(
                                'base' => add_query_arg('pageid', '%#%'),
                                'format' => '?pageid=%#%',
                                'total' => $query->max_num_pages,
                                'current' => $current,
                                'show_all' => false,
                                'end_size' => 1,
                                'mid_size' => 2,
                                'prev_next' => true,
                                'type' => 'plain',
                                'add_args' => false,
                                'add_fragment' => '',
                                'prev_text'    => __('<i class="fas fa-angle-left"></i>'),
                                'next_text'    => __('<i class="fas fa-angle-right"></i>')
                            ));
                        ?>
                    </div>
                </div>
            </div>
        </div>
    </section>
<?php
    wp_reset_postdata();
    }
?>

        <?php
    }
}


Plugin::instance()->widgets_manager->register_widget_type( new \Page_Gallery() );