<?php
  use Elementor\Utils;

class LoveUsLatestPosts extends \Elementor\Widget_Base {



	public function get_name() {
		return 'loveus_latest_posts';
	}

	public function get_title() {
		return esc_html__( ' LoveUs Latest Posts', 'plugin-domain' );
	}

	public function get_icon() {
		return '';
	}

	public function get_categories() {
		return [ 'plugin-domain' ];
	}

	private function get_blog_categories() {
        $options = array();
        $taxonomy = 'category';
        if (!empty($taxonomy)) {
            $terms = get_terms(
                    array(
                        'parent' => 0,
                        'taxonomy' => $taxonomy,
                        'hide_empty' => true,
                    )
            );
            if (!empty($terms)) {
                foreach ($terms as $term) {
                    if (isset($term)) {
                        if (isset($term->slug) && isset($term->name)) {
                            $options[$term->slug] = $term->name;
                        }
                    }
                }
            }
        }
        return $options;
	}
	
	protected function _register_controls() {

		$this->start_controls_section(
			'general',
			[
				'label' => __( 'General', 'plugin-domain' ),
			]
		);

		$this->add_control(
			'title',
			[
				'label'   => __( 'Title', 'plugin-domain' ),
				'type'    => \Elementor\Controls_Manager::TEXT,
				'default' => __( 'News', 'plugin-domain' ),
			]
		);
		$this->add_control(
			'sub_title',
			[
				'label'   => __( 'Sub Title', 'plugin-domain' ),
				'type'    => \Elementor\Controls_Manager::TEXT,
				'default' => __( 'Latest Articles', 'plugin-domain' ),

			]
		);

		$this->add_control(
			'showposts',
			[
				'label'   => __( 'Number of Posts', 'plugin-domain' ),
				'type'    => \Elementor\Controls_Manager::TEXT,
				'default' => __( '4', 'plugin-domain' ),

			]
		);
		$this->add_control(
			'orderby',
			[
				'label'   => __( 'Order By', 'plugin-domain' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'date'     => __( 'Date', 'plugin-domain' ),
					'id'       => __( 'ID', 'plugin-domain' ),
					'title'    => __( 'Title', 'plugin-domain' ),
					'name'     => __( 'Name', 'plugin-domain' ),
					'modified' => __( 'Modified', 'plugin-domain' ),
					'rand'     => __( 'Rand', 'plugin-domain' ),
				],
				'default' => 'id',

			]
		);
		$this->add_control(
			'order',
			[
				'label'   => __( 'Sort Order', 'plugin-domain' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'desc' => __( 'Descending', 'plugin-domain' ),
					'asc'  => __( 'Ascending', 'plugin-domain' ),
				],
				'default' => 'asc',

			]
		);

		$this->add_control(
			'button_text',
			[
				'label'   => __( 'Button Text', 'plugin-domain' ),
				'type'    => \Elementor\Controls_Manager::TEXT,
				'default' => __( 'Latest Articles', 'plugin-domain' ),

			]
		);

		$this->add_control(
			'catagory_name', [
			'type' => \Elementor\Controls_Manager::SELECT,
			'label' => esc_html__('Category', 'plugin-name'),
			'default' => __( 'uncategorized', 'plugin-domain' ),
			'options' => $this->get_blog_categories()
				]

				
		);

		$this->end_controls_section();

	}

	protected function render() {
		$settings    = $this->get_settings_for_display();
		$title       = $settings['title'];
		$sub_title   = $settings['sub_title'];
		$showposts   = $settings['showposts'];
		$orderby     = $settings['orderby'];
		$order       = $settings['order'];
		$button_text = $settings['button_text'];
		$catagory_name = ucwords($settings['catagory_name']);
		$args = array(
			'post_type'      => array( 'post' ),
			'tax_query' => array(
				array (
					'taxonomy' => 'category',
					'field' => 'slug',
					'terms' => $catagory_name,
				)
			),
			'posts_per_page' => $showposts,
			'order'          => $order,
			'orderby'        => $orderby,
		);

		?>


<section class="news-section style-two">
        <div class="anim-icon">
            <div class="icon icon-2 wow zoomIn" data-wow-delay="00ms" data-wow-duration="1500ms"></div>
        </div>
        <div class="container">
            <div class="sec-title centred">
                <h5><?php echo $title; ?></h5>
                <h1><?php echo $sub_title; ?></h1>
            </div>


            <div class="row">
			<?php
			$blogs = new WP_Query( $args );
			if ( $blogs->have_posts() ) {
				$countpost = 1;
				while ( $blogs->have_posts() ) {
					$blogs->the_post();
					$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
					if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
						$time_string = '<time class="updated" datetime="%3$s">%4$s</time>';
					}

					$time_string   = sprintf(
						$time_string,
						esc_attr( get_the_date( DATE_W3C ) ),
						esc_html( get_the_date() ),
						esc_attr( get_the_modified_date( DATE_W3C ) ),
						esc_html( get_the_modified_date() )
					);
					$thumbnail_url = get_the_post_thumbnail_url();
					if ( $countpost == 1 ) {
						?>

                <div class="col-xl-6 col-lg-12 col-md-12 news-block">
                    <div class="news-block-two wow fadeInUp" data-wow-delay="00ms" data-wow-duration="1500ms">
                        <div class="inner-box">
                            <figure class="image-box"><a href="<?php the_permalink(); ?>"><img src="<?php echo $thumbnail_url; ?>" data-src="<?php echo $thumbnail_url; ?>" alt="alt"></a></figure>
                            <div class="lower-content">
                                <ul class="info-box">
                                    <li><?php echo get_the_date( ); ?></li>
                                    <li><?php echo get_comments_number( get_the_ID() ); ?> Comments</li>
                                </ul>
                                <h3><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h3>
                                <div class="text"><?php the_excerpt(); ?></div>
                                <div class="link-btn"><a href="<?php the_permalink(); ?>" class="theme-btn">Read More</a></div>
                            </div>
                        </div>
                    </div>
                </div>
				<?php
							$countpost++;
					} elseif ( $countpost > 1 && $countpost <= 4 ) {
						if ( $countpost == 2 ) {
							?>
                <div class="col-xl-6 col-lg-12 col-md-12 news-block">
				<?php
						}
						?>
                    <div class="news-block-two wow fadeInUp" data-wow-delay="300ms" data-wow-duration="1500ms">
                        <div class="inner-box">
                            <div class="lower-content">
                                <ul class="info-box">
									<li><?php echo get_the_date( ); ?></li>
                                    <li><?php echo get_comments_number( get_the_ID() ); ?> Comments</li>
                                </ul>
                                <h3><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h3>
                                <div class="text"><?php the_excerpt(); ?></div>
                            </div>
                        </div>
                    </div>
                    
					<?php
						if ( $countpost == 4 ) {
							?>
                </div>
				<?php
						}
						$countpost++;
						if ( $countpost > 4 ) {
							$countpost = 1;
						}
					}
				}
				wp_reset_postdata();
			}
			?>


            </div>
        </div>
    </section>




















		<?php
	}

	protected function _content_template() {

	}
}

  \Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \LoveUsLatestPosts() );
